@@ -7,7 +7,7 @@ with the Claude LLM.
 
 from meta_ads_mcp.core.server import main
 
-__version__ = "0.3.10"
+__version__ = "0.7.3"
 
 __all__ = [
     'get_ad_accounts',
@@ -24,10 +24,15 @@ __all__ = [
     'get_ad_image',
     'update_ad',
     'get_insights',
-    'debug_image_download',
     'get_login_link',
     'login_cli',
-    'main'
+    'main',
+    'search_interests',
+    'get_interest_suggestions',
+    'validate_interests',
+    'search_behaviors',
+    'search_demographics',
+    'search_geo_locations'
 ]
 
 # Import key functions to make them available at package level
@@ -46,10 +51,15 @@ from .core import (
     get_ad_image,
     update_ad,
     get_insights,
-    debug_image_download,
     get_login_link,
     login_cli,
-    main
+    main,
+    search_interests,
+    get_interest_suggestions,
+    validate_interests,
+    search_behaviors,
+    search_demographics,
+    search_geo_locations
 )
 
 # Define a main function to be used as a package entry point
