@@ -5,13 +5,16 @@ from .accounts import get_ad_accounts, get_account_info
 from .campaigns import get_campaigns, get_campaign_details, create_campaign
 from .adsets import get_adsets, get_adset_details, update_adset
 from .ads import get_ads, get_ad_details, get_ad_creatives, get_ad_image, update_ad
-from .insights import get_insights, debug_image_download
+from .insights import get_insights
 from .authentication import get_login_link
 from .server import login_cli, main
 from .auth import login
 from .ads_library import search_ads_archive
 from .budget_schedules import create_budget_schedule
+from .targeting import search_interests, get_interest_suggestions, validate_interests, search_behaviors, search_demographics, search_geo_locations
 from . import reports  # Import module to register conditional tools
+from . import duplication  # Import module to register conditional duplication tools
+from .openai_deep_research import search, fetch  # OpenAI MCP Deep Research tools
 
 __all__ = [
     'mcp_server',
@@ -29,11 +32,18 @@ __all__ = [
     'get_ad_image',
     'update_ad',
     'get_insights',
-    'debug_image_download',
     'get_login_link',
     'login_cli',
     'login',
     'main',
     'search_ads_archive',
     'create_budget_schedule',
+    'search_interests',
+    'get_interest_suggestions',
+    'validate_interests',
+    'search_behaviors',
+    'search_demographics',
+    'search_geo_locations',
+    'search',  # OpenAI MCP Deep Research search tool
+    'fetch',   # OpenAI MCP Deep Research fetch tool
 ] 
\ No newline at end of file
