@@ -10,7 +10,7 @@ import time
 
 from .api import meta_api_tool, make_api_request
 from .accounts import get_ad_accounts
-from .utils import download_image, try_multiple_download_methods, ad_creative_images
+from .utils import download_image, try_multiple_download_methods, ad_creative_images, extract_creative_image_urls
 from .server import mcp_server
 
 
@@ -38,26 +38,27 @@ async def get_ads(access_token: str = None, account_id: str = None, limit: int =
         else:
             return json.dumps({"error": "No account ID specified and no accounts found for user"}, indent=2)
     
+    # Prioritize adset_id over campaign_id - use adset-specific endpoint
+    if adset_id:
+        endpoint = f"{adset_id}/ads"
+        params = {
+            "fields": "id,name,adset_id,campaign_id,status,creative,created_time,updated_time,bid_amount,conversion_domain,tracking_specs",
+            "limit": limit
+        }
     # Use campaign-specific endpoint if campaign_id is provided
-    if campaign_id:
+    elif campaign_id:
         endpoint = f"{campaign_id}/ads"
         params = {
             "fields": "id,name,adset_id,campaign_id,status,creative,created_time,updated_time,bid_amount,conversion_domain,tracking_specs",
             "limit": limit
         }
-        # Adset ID can still be used to filter within the campaign
-        if adset_id:
-            params["adset_id"] = adset_id
     else:
-        # Default to account-level endpoint if no campaign_id
+        # Default to account-level endpoint if no specific filters
         endpoint = f"{account_id}/ads"
         params = {
             "fields": "id,name,adset_id,campaign_id,status,creative,created_time,updated_time,bid_amount,conversion_domain,tracking_specs",
             "limit": limit
         }
-        # Adset ID can filter at the account level if no campaign specified
-        if adset_id:
-            params["adset_id"] = adset_id
 
     data = await make_api_request(endpoint, access_token, params)
     
@@ -178,7 +179,7 @@ async def get_ad_creatives(access_token: str = None, ad_id: str = None) -> str:
     # Add image URLs for direct viewing if available
     if 'data' in data:
         for creative in data['data']:
-            creative['image_urls_for_viewing'] = ad_creative_images(creative)
+            creative['image_urls_for_viewing'] = extract_creative_image_urls(creative)
 
     return json.dumps(data, indent=2)
 
@@ -249,18 +250,72 @@ async def get_ad_image(access_token: str = None, ad_id: str = None) -> Image:
     
     if not image_hashes:
         # If no hashes found, try to extract from the first creative we found in the API
-        # Get creative for ad to try to extract hash
-        creative_json = await get_ad_creatives(ad_id, "", access_token)
+        # and also check for direct URLs as fallback
+        creative_json = await get_ad_creatives(access_token=access_token, ad_id=ad_id)
         creative_data = json.loads(creative_json)
         
-        # Try to extract hash from asset_feed_spec
-        if "asset_feed_spec" in creative_data and "images" in creative_data["asset_feed_spec"]:
-            images = creative_data["asset_feed_spec"]["images"]
-            if images and len(images) > 0 and "hash" in images[0]:
-                image_hashes.append(images[0]["hash"])
-    
-    if not image_hashes:
-        return "Error: No image hashes found in creative"
+        # Try to extract hash from data array
+        if "data" in creative_data and creative_data["data"]:
+            for creative in creative_data["data"]:
+                # Check object_story_spec for image hash
+                if "object_story_spec" in creative and "link_data" in creative["object_story_spec"]:
+                    link_data = creative["object_story_spec"]["link_data"]
+                    if "image_hash" in link_data:
+                        image_hashes.append(link_data["image_hash"])
+                # Check direct image_hash on creative
+                elif "image_hash" in creative:
+                    image_hashes.append(creative["image_hash"])
+                # Check asset_feed_spec for image hashes
+                elif "asset_feed_spec" in creative and "images" in creative["asset_feed_spec"]:
+                    images = creative["asset_feed_spec"]["images"]
+                    if images and len(images) > 0 and "hash" in images[0]:
+                        image_hashes.append(images[0]["hash"])
+        
+        # If still no image hashes found, try direct URL fallback approach
+        if not image_hashes:
+            print("No image hashes found, trying direct URL fallback...")
+            
+            image_url = None
+            if "data" in creative_data and creative_data["data"]:
+                creative = creative_data["data"][0]
+                
+                # Try image_urls_for_viewing first (usually higher quality)
+                if "image_urls_for_viewing" in creative and creative["image_urls_for_viewing"]:
+                    image_url = creative["image_urls_for_viewing"][0]
+                    print(f"Using image_urls_for_viewing: {image_url}")
+                # Fall back to thumbnail_url
+                elif "thumbnail_url" in creative and creative["thumbnail_url"]:
+                    image_url = creative["thumbnail_url"]
+                    print(f"Using thumbnail_url: {image_url}")
+            
+            if not image_url:
+                return "Error: No image URLs found in creative"
+            
+            # Download the image directly
+            print(f"Downloading image from direct URL: {image_url}")
+            image_bytes = await download_image(image_url)
+            
+            if not image_bytes:
+                return "Error: Failed to download image from direct URL"
+            
+            try:
+                # Convert bytes to PIL Image
+                img = PILImage.open(io.BytesIO(image_bytes))
+                
+                # Convert to RGB if needed
+                if img.mode != "RGB":
+                    img = img.convert("RGB")
+                    
+                # Create a byte stream of the image data
+                byte_arr = io.BytesIO()
+                img.save(byte_arr, format="JPEG")
+                img_bytes = byte_arr.getvalue()
+                
+                # Return as an Image object that LLM can directly analyze
+                return Image(data=img_bytes, format="jpeg")
+                
+            except Exception as e:
+                return f"Error processing image from direct URL: {str(e)}"
     
     print(f"Found image hashes: {image_hashes}")
     
@@ -805,11 +860,74 @@ async def get_account_pages(access_token: str = None, account_id: str = None) ->
                 if page_details["data"]:
                     return json.dumps(page_details, indent=2)
         
+        # Approach 4: Extract page IDs from tracking_specs in ads
+        # Inspired by praveen92y's implementation for robust page detection
+        # This approach is often the most reliable as confirmed by community feedback
+        endpoint = f"{account_id}/ads"
+        params = {
+            "fields": "id,name,adset_id,campaign_id,status,creative,created_time,updated_time,bid_amount,conversion_domain,tracking_specs",
+            "limit": 100
+        }
+        
+        tracking_ads_data = await make_api_request(endpoint, access_token, params)
+        
+        tracking_page_ids = set()
+        if "data" in tracking_ads_data:
+            for ad in tracking_ads_data.get("data", []):
+                tracking_specs = ad.get("tracking_specs", [])
+                if isinstance(tracking_specs, list):
+                    for spec in tracking_specs:
+                        # If 'page' key exists, add all page IDs
+                        if isinstance(spec, dict) and "page" in spec:
+                            page_list = spec["page"]
+                            if isinstance(page_list, list):
+                                for page_id in page_list:
+                                    # Validate page ID format (should be numeric string)
+                                    if isinstance(page_id, (str, int)) and str(page_id).isdigit():
+                                        tracking_page_ids.add(str(page_id))
+        
+        if tracking_page_ids:
+            page_details = {"data": [], "source": "tracking_specs", "note": "Page IDs extracted from active ads - these are the most reliable for ad creation"}
+            for page_id in tracking_page_ids:
+                page_endpoint = f"{page_id}"
+                page_params = {
+                    "fields": "id,name,username,category,fan_count,link,verification_status,picture"
+                }
+                
+                page_data = await make_api_request(page_endpoint, access_token, page_params)
+                if "id" in page_data:
+                    # Add additional context about this page ID being suitable for ads
+                    page_data["_meta"] = {
+                        "suitable_for_ads": True,
+                        "found_in_tracking_specs": True,
+                        "recommended_for_create_ad_creative": True
+                    }
+                    page_details["data"].append(page_data)
+                else:
+                    page_details["data"].append({
+                        "id": page_id, 
+                        "error": "Page details not found",
+                        "_meta": {
+                            "suitable_for_ads": True,
+                            "found_in_tracking_specs": True,
+                            "note": "Page ID exists in ads but details not accessible - you can still use this ID for ad creation"
+                        }
+                    })
+            
+            if page_details["data"]:
+                return json.dumps(page_details, indent=2)
+        
         # If all approaches failed, return empty data with a message
         return json.dumps({
             "data": [],
-            "message": "No pages found associated with this account",
-            "suggestion": "You may need to create a page or provide a page_id explicitly when creating ads"
+            "message": "No pages found associated with this account using automated methods",
+            "troubleshooting": {
+                "suggestion_1": "If you have existing ads, run 'get_ads' and look for page IDs in the 'tracking_specs' field",
+                "suggestion_2": "Use the exact page ID from existing ads' tracking_specs for creating new ad creatives",
+                "suggestion_3": "Verify your page ID format - it should be a numeric string (e.g., '123456789')",
+                "suggestion_4": "Check for digit transpositions or formatting errors in your page ID"
+            },
+            "note": "Based on community feedback, page IDs from existing ads' tracking_specs are the most reliable for ad creation"
         }, indent=2)
         
     except Exception as e:
