@@ -23,7 +23,9 @@ from .callback_server import (
 from .pipeboard_auth import pipeboard_auth_manager
 
 # Auth constants
-AUTH_SCOPE = "ads_management,ads_read,business_management,public_profile"
+# Scope includes pages_show_list and pages_read_engagement to fix issue #16
+# where get_account_pages failed for regular users due to missing page permissions
+AUTH_SCOPE = "ads_management,ads_read,business_management,public_profile,pages_show_list,pages_read_engagement"
 AUTH_REDIRECT_URI = "http://localhost:8888/callback"
 AUTH_RESPONSE_TYPE = "token"
 
@@ -216,22 +218,27 @@ class AuthManager:
             return self.token_info.access_token
         
         # Start the callback server if not already running
-        port = start_callback_server()
-        
-        # Update redirect URI with the actual port
-        self.redirect_uri = f"http://localhost:{port}/callback"
-        
-        # Generate the auth URL
-        auth_url = self.get_auth_url()
-        
-        # Open browser with auth URL
-        logger.info(f"Opening browser with URL: {auth_url}")
-        webbrowser.open(auth_url)
-        
-        # We don't wait for the token here anymore
-        # The token will be processed by the callback server
-        # Just return None to indicate we've started the flow
-        return None
+        try:
+            port = start_callback_server()
+            
+            # Update redirect URI with the actual port
+            self.redirect_uri = f"http://localhost:{port}/callback"
+            
+            # Generate the auth URL
+            auth_url = self.get_auth_url()
+            
+            # Open browser with auth URL
+            logger.info(f"Opening browser with URL: {auth_url}")
+            webbrowser.open(auth_url)
+            
+            # We don't wait for the token here anymore
+            # The token will be processed by the callback server
+            # Just return None to indicate we've started the flow
+            return None
+        except Exception as e:
+            logger.error(f"Failed to start callback server: {e}")
+            logger.info("Callback server disabled. OAuth authentication flow cannot be used.")
+            return None
     
     def get_access_token(self) -> Optional[str]:
         """
@@ -477,7 +484,14 @@ def login():
     
     try:
         # Start the callback server first
-        port = start_callback_server()
+        try:
+            port = start_callback_server()
+        except Exception as callback_error:
+            print(f"Error: {callback_error}")
+            print("Callback server is disabled. Please use alternative authentication methods:")
+            print("- Set PIPEBOARD_API_TOKEN environment variable for Pipeboard authentication")
+            print("- Or provide a direct META_ACCESS_TOKEN environment variable")
+            return
         
         # Get the auth URL and open the browser
         auth_url = auth_manager.get_auth_url()
